@@ -96,6 +96,11 @@
  *    - Explicitly set alias device types (could be wrong)
  *    - Check blk vs. chr devtype when updating dev node
  *  -> 2.26
+ * 
+ *  * 2002/08/07: Kurt Garloff <garloff@suse.de>
+ *    - Fix usage message
+ *  -> 2.27
+ * 
  */
 
 #include <stdio.h>
@@ -116,8 +121,8 @@
 #include <ctype.h>
 
 
-static char rcsid[] ="$Id: scsidev.c,v 1.28.2.18 2002/08/07 07:49:36 garloff Exp $";
-static char *versid = "scsidev " VERSION " 2000/01/17";
+static char rcsid[] ="$Id: scsidev.c,v 1.28.2.19 2002/08/07 09:09:19 garloff Exp $";
+static char *versid = "scsidev " VERSION " 2002/08/07";
 static char *copyright = "Copyright: GNU GPL  (see file COPYING)\n" \
 " (w)  1994--1997 Eric Youngdale <eric@andante.org>\n"\
 "      2000--2002 Kurt Garloff   <garloff@suse.de>";
@@ -150,6 +155,7 @@ int maxmiss = 8;
 int force = 0;
 int san_del = 0;
 int no_san = 0;
+int no_procscsi = 0;
 int nm_cbtu = 0;
 int supp_rmvbl = 0;
 int override_link_perm = 1;
@@ -1849,7 +1855,7 @@ void usage()
     fprintf (stderr, "Usage: scsidev [options]\n");
     fprintf (stderr, " -f     : Force deletion of all " DEVSCSI" entries\n");
     fprintf (stderr, " -n     : Nosanitize: leaved undetected entries untouched\n");
-    fprintf (stderr, " -d     : sanitize by Deleting undetected entries (def: minor->255)\n");
+    fprintf (stderr, " -d     : sanitize by Deleting undetected entries (def: .shadow. files\n");
     fprintf (stderr, " -l/-L  : create symLinks for device names / alias names\n");
     fprintf (stderr, " -m mode: permissions to create dev nodes with\n");
     fprintf (stderr, " -s     : list Serial numbers /WWIDs of devices (if available)\n");
@@ -1876,8 +1882,10 @@ int main (int argc, char * argv[])
 	fprintf(stderr, DEVSCSI " either does not exist, or is not a directory\n");
 	exit(0);
     }
-    while ((c = getopt(argc, argv, "flLvqshnderm:c:")) != EOF) {
+    while ((c = getopt(argc, argv, "pflLvqshnderm:c:")) != EOF) {
 	switch (c) {
+	  case 'p':
+	    no_procscsi = 1; break;
 	  case 'f':
 	    force = 1; break;
 	  case 'm':
@@ -1927,7 +1935,7 @@ int main (int argc, char * argv[])
     register_dev("/dev/scsi/sth4-334c0i5l0",  9,  0, ST, 6, 0x334, 0, 5, 0, -1, "debug", 0, NULL, NULL);
     register_dev("/dev/scsi/rsth4-334c0i5l0", 9,128, ST, 6, 0x334, 0, 5, 0, -1, "debug", 0, NULL, NULL);
 #else
-    if (try_procscsi ()) {
+    if (no_procscsi || try_procscsi ()) {
 	if (!quiet) 
 	    fprintf (stderr, "/proc/scsi/scsi extensions not found. Fall back to scanning.\n");
 	build_sgdevlist ();
